@@ -1,6 +1,6 @@
 from pydantic import BaseModel, Field, root_validator
 from caseconverter import camelcase
-from typing import Any
+from typing import Any, Optional, Dict
 import typing
 
 # import deeplabel.client
@@ -14,12 +14,13 @@ class MixinConfig(BaseModel):
 
 class DeeplabelBase(MixinConfig):
     """Base Model for all models that don't need client"""
-    extra: typing.Dict[str, Any] = Field(exclude=True)
-    client: Any = Field(exclude=True)
+    extra:Optional[Dict[str, Any]] = Field(exclude=True, default=dict)
+    client: Any = Field(default=None, exclude=True)
 
     @root_validator(pre=True)
     def build_extra(cls, values: typing.Dict[str, Any]) -> typing.Dict[str, Any]:
         all_required_field_names = {field.alias for field in cls.__fields__.values() if field.alias != 'extra'}  # to support alias
+        all_required_field_names = all_required_field_names.union({field.name for field in cls.__fields__.values() if field.alias != 'extra'})  # to support field.name
 
         extra: typing.Dict[str, Any] = {}
         for field_name in list(values):
