@@ -11,6 +11,7 @@ from deeplabel.exceptions import InvalidIdError
 from deeplabel.basemodel import DeeplabelBase, MixinConfig
 from pydantic import conint, Field, validate_arguments
 from logging import getLogger
+import json
 
 logger = getLogger(__name__)
 
@@ -97,12 +98,12 @@ class GalleryTask(DeeplabelBase):
         for dets in chunk(detections, chunk_size):
             dets: List[gallery_detections.Detection]
             data = [
-                det.dict(by_alias=True, exclude_unset=True, exclude_none=True)
+                json.loads(det.json(by_alias=True, exclude_none=True))
                 for det in dets
             ]
             logger.debug(f"Pushing ({count} ~ {count+len(data)})/{len(detections)}")
             count += len(data)
-            self.client.post("/image-detections", {"batch":True, "data": data})
+            self.client.post("/image-detections", {"batch":True, "data": data, "galleryTaskId":self.gallery_task_id})
         logger.debug(
             f"Completed pushing {len(detections)} detections for galleryTaskId: {self.gallery_task_id}"
         )
