@@ -19,7 +19,7 @@ class Image(DeeplabelBase):
         resp = client.get("/images", params=params)
         images = resp.json()["data"]["images"]
         images = [cls(**image, client=client) for image in images]
-        return images
+        return images #type: ignore
     
     @classmethod
     def from_image_id(cls, image_id:str, client: "deeplabel.client.BaseClient")->"Image":
@@ -29,5 +29,5 @@ class Image(DeeplabelBase):
         return image[0]
 
     @classmethod
-    def from_gallery_id(cls, gallery_id:str, client: "deeplabel.client.BaseClient")->List["Image"]:
-        return cls._from_search_params({"galleryId":gallery_id}, client=client)
+    def from_gallery_and_project_id(cls, gallery_id:str, project_id:str, client: "deeplabel.client.BaseClient")->List["Image"]:
+        return cls._from_search_params({"galleryId":gallery_id,'projectId':project_id}, client=client)
