@@ -2,21 +2,31 @@
 Module to get detections data
 """
 from typing import Any, List, Optional, Dict
+from enum import Enum
 from pydantic import Field
 from deeplabel.basemodel import DeeplabelBase
 import deeplabel.client
 from deeplabel.exceptions import InvalidIdError
 from deeplabel.infer.types import Sequence
 from deeplabel.types.bounding_box import BoundingBoxWithNumber as BoundingBox
+from deeplabel.types.polygon import Polygon
+
+
+class DetectionType(Enum):
+    BOUNDING_BOX='BOUNDING_BOX'
+    POLYGON='POLYGON'
+    CLASSIFICATION='CLASSIFICATION'
 
 
 class Detection(DeeplabelBase):
     video_task_id: str
     probability: float
     time: float
+    type:DetectionType = DetectionType.BOUNDING_BOX
     label: str = Field(alias="class")  # type: ignore
     sequence: Optional[Sequence] = None
     bounding_box: Optional[BoundingBox] = None
+    polygon: Optional[Polygon] = None
     sub_class: List[str] = Field(default_factory=list)
 
     @classmethod
