@@ -11,6 +11,7 @@ from deeplabel.exceptions import InvalidIdError
 from deeplabel.basemodel import DeeplabelBase, MixinConfig
 from pydantic import Field, conint, validate_arguments, validator
 from logging import getLogger
+import json
 
 logger = getLogger(__name__)
 
@@ -144,12 +145,12 @@ class VideoTask(DeeplabelBase):
         for dets in chunk(detections, chunk_size):
             dets: List[deeplabel.infer.videos.detections.Detection]
             data = [
-                det.dict(by_alias=True, exclude_unset=True, exclude_none=True)
+                json.loads(det.json(by_alias=True, exclude_none=True))
                 for det in dets
             ]
             logger.debug(f"Pushing ({count} ~ {count+len(data)})/{len(detections)}")
             count += len(data)
-            self.client.post("/detections", {"data": data, "batch": True})
+            self.client.post("/detections", {"data": data, "batch": True, "videoTaskId":self.video_task_id})
         logger.info(
             f"Completed pushing {len(detections)} detections for videoTaskId: {self.video_task_id}"
         )
