@@ -1,10 +1,9 @@
 from enum import Enum
-from re import L
 from typing import List, Optional, Dict, Any
 from deeplabel.basemodel import DeeplabelBase, MixinConfig
 import deeplabel.label.gallery.images
 import deeplabel.client
-from deeplabel.exceptions import InvalidAPIResponse
+from deeplabel.exceptions import InvalidAPIResponse, InvalidIdError
 import logging
 logger = logging.getLogger(__name__)
 
@@ -55,7 +54,18 @@ class Gallery(DeeplabelBase):
         resp = client.get("/projects/gallery", params=params)
         galleries = resp.json()["data"]["gallery"]
         galleries = [cls(**gallery, client=client) for gallery in galleries]
-        return galleries
+        return galleries #type:ignore
+    
+    @classmethod
+    def from_gallery_id(cls, gallery_id:str, client:"deeplabel.client.BaseClient")->"Gallery":
+        galleries = cls._from_search_params({"galleryId": gallery_id}, client)
+        if not len(galleries):
+            raise InvalidIdError(
+                f"Failed to fetch gallery with galleryId  : {gallery_id}"
+            )
+        # since galleryId should fetch only 1 gallery, return that gallery instead of a list
+        return galleries[0]
+
 
     @property
     def images(self)->List["deeplabel.label.gallery.images.Image"]:
